#!/usr/bin/env python3
# encoding: utf-8
"""
Installation script for sim_cca.

Usage:
    python setup.py install
"""

from setuptools import setup
from distutils.util import convert_path


def read_file(path):
    """Read a file in binary mode."""
    with open(convert_path(path), 'rb') as f:
        return f.read()


def exec_file(path):
    """Execute a python file and return the `globals` dictionary."""
    namespace = {}
    exec(read_file(path), namespace, namespace)
    return namespace


def main():
    """Execute setup."""
    long_description = read_file('README.rst').decode('utf-8')
    meta = exec_file('sim_cca/__init__.py')
    setup(
        name='sim_cca',
        version=meta['__version__'],
        description=meta['__summary__'],
        long_description=long_description,
        author=meta['__author__'],
        author_email=meta['__email__'],
        url=meta['__uri__'],
        license=meta['__license__'],
        classifiers=meta['__classifiers__'],
        packages=[
            'sim_cca',
        ],
        install_requires=[
            'docopt',
            'numpy',
            'sympy',
        ],
        entry_points="""
            [console_scripts]
            sim_cca = sim_cca.main:main
        """,
    )


if __name__ == '__main__':
    main()
