"""
Wrapper module for symbolic math operation.

This module wraps some numpy/sympy functions in order to provide a common
interface with the 'numeric_math' module that can be used for purely numeric
calculations.
"""

import numpy
import sympy


__all__ = [
    'integer',
    'rational',
    'log',
    'full',
    'ones',
    'zeros',
    'ndenumerate',
    'simplify',
]


# number creation
integer = sympy.Integer

rational = sympy.Rational


# math functions
log = sympy.log


# array creation
def full(shape, value):
    return numpy.full(shape, value, dtype=object)

def ones(shape):
    return full(shape, integer(1))

def zeros(shape):
    return full(shape, integer(0))


# array iteration
ndenumerate = numpy.ndenumerate


# symbolic operations
def simplify(expr):
    return sympy.expand(sympy.factor(expr))
